@@ -2,7 +2,7 @@
 #
 # This file is part of Config-Model-OpenSsh
 #
-# This software is Copyright (c) 2008-2021 by Dominique Dumont.
+# This software is Copyright (c) 2008-2022 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -13,6 +13,7 @@ use strict;
 use warnings;
 use 5.22.0;
 use utf8;
+use open      qw(:std :utf8);    # undeclared streams in UTF-8
 
 use lib 'contrib/lib';
 
@@ -31,15 +32,16 @@ use ParseMan;
 path('lib/Config/Model/models/')->remove_tree;
 
 sub parse_man_page ($man_page_name) {
+    my $path = `man --path $man_page_name`;
+    chomp $path;
     my $pipe = IO::Pipe->new();
-    $pipe->reader("roff2html $man_page_name");
+    $pipe->reader("zcat $path | man2html");
     my @lines = $pipe->getlines;
     $pipe->close;
     return parse_html_man_page(join('',@lines));
 }
 
 sub store_description ($obj, @desc) {
-    shift @desc; # remove keyword
     $obj->fetch_element("description")->store(join("\n\n", @desc));
 }
 
@@ -114,9 +116,10 @@ load_yaml_model($meta_root,"Ssh::PortForward");
 say "Creating ssh model...";
 create_ssh_model($meta_root);
 
-say "loading ssh model addendum";
+say "loading ssh model addendum from ssh-fixup.yaml";
 $meta_root->load_data(LoadFile('contrib/ssh-fixup.yaml'));
-say "loading ssh model IPQoS element";
+
+say "loading ssh model IPQoS element from fixup-element-ipqos.yml";
 $meta_root
     ->grab("class:Ssh::HostElement element:IPQoS")
     ->load_data(LoadFile('contrib/fixup-element-ipqos.yml'));
@@ -133,12 +136,13 @@ load_yaml_model($meta_root,"Sshd::MatchCondition");
 
 create_sshd_model($meta_root);
 
-say "loading sshd model addendum";
-
 # requires Sshd::MatchElement
 load_yaml_model($meta_root,"Sshd::MatchBlock");
 
+say "loading sshd model addendum from sshd-fixup.yaml";
 $meta_root->load_data(LoadFile('contrib/sshd-fixup.yaml'));
+
+say "loading ssh model IPQoS element from fixup-element-ipqos.yml";
 $meta_root
     ->grab("class:Sshd::MatchElement element:IPQoS")
     ->load_data(LoadFile('contrib/fixup-element-ipqos.yml'));
